@@ -7,7 +7,6 @@ import argparse
 import os
 from pathlib import Path
 import traceback
-import shlex
 import subprocess
 import sys
 
@@ -89,6 +88,7 @@ class DeviceManager(object):
         print('8. Secure erase ({})'.format(
             erase_methods[next_erase_method].name))
         print('D. Dispose HDD in security container')
+        print('L. Enable the locate LED')
         print('P. Show current info/status (again)')
 
         print('')
@@ -224,6 +224,12 @@ class DeviceManager(object):
 
         return result is False  # false = we found non-zero
 
+    def led_failure(self):
+        self._hdd_dock.led_failure()
+
+    def led_locate(self):
+        self._hdd_dock.led_locate()
+
 
 def register_disk(**kwargs):
     # Python2-compatible forced kwargs. Temporary fix until we clean up this
@@ -279,7 +285,7 @@ def register_disk(**kwargs):
     input('Registration complete, press enter')
 
 
-def registered_disk_actions(action=None, **kwargs):
+def registered_disk_actions(auto_action=None, owner='', **kwargs):
     # Python2-compatible forced kwargs. Temporary fix until we clean up this
     # code.
     hdd_dock = kwargs.pop('hdd_dock')
@@ -324,40 +330,42 @@ def registered_disk_actions(action=None, **kwargs):
         hdd_dock, hdd_id, inventory_rest_client, author, location)
     manager.show_summary(_build_print_data())
 
-    if action == 'secure-erase':
-        if 'SECURE ERASED' in inventory.current_health_status:
-            print(
-                'Skipping automatic secure erase, health says it\'s been done')
-        else:
-            print('Starting automatic secure erase')
-            manager.best_erase()
-            inventory.flush()
-
-    manager.show_commands()
+    is_auto = bool(auto_action)
+    show_commands = bool(not is_auto)
 
     while True:
-        action = input('\nAction: ').upper()
+        if not is_auto and show_commands:
+            manager.show_commands()
+            show_commands = False
 
-        if action == '1':
-            owner = ''
+        if auto_action:
+            action = auto_action.pop(0)
+            print(f'\x1b[1mAUTOMATIC ACTION:\x1b[0m {action}')
+        else:
+            if is_auto:
+                manager.show_commands()
+                is_auto = False
+            action = input('\nAction: ').upper()
+
+        if action in ('1', 'set-owner'):
             while len(owner) == 0:
                 owner = input('New owner: ')
             inventory_rest_client.add_owner(  # XXX: not email-of-owner
                 hdd_id, name=owner, email=author)
             inventory.flush()
 
-        elif action == '2':
+        elif action in ('2', 'print-label'):
             # Print label
             labelprinter_rest_client = get_labelprinter()
             labelprinter_rest_client.print_hdd_label(
                 inventory.tag_uid, hdd_dock.get_serial_number(),
                 inventory.current_owner)
 
-        elif action == '3':
+        elif action in ('3', 'quick-erase'):
             manager.quick_erase()
             inventory.flush()
 
-        elif action == '4':
+        elif action in ('4', 'secure-erase'):
             manager.best_erase()
             inventory.flush()
 
@@ -375,7 +383,7 @@ def registered_disk_actions(action=None, **kwargs):
             manager.set_health_with_wear(health_status)
             inventory.flush()
 
-        elif action == '7':
+        elif action in ('7', 'print-health-label'):
             # Print label
             print_health_label(hdd_dock, inventory, author, dynamic_data)
 
@@ -383,7 +391,7 @@ def registered_disk_actions(action=None, **kwargs):
             manager.second_best_erase()
             inventory.flush()
 
-        elif action == '9':
+        elif action in ('9', 'eject'):
             break  # Quit + EJECT
 
         elif action == 'D':
@@ -397,9 +405,12 @@ def registered_disk_actions(action=None, **kwargs):
             inventory.flush()
             break
 
+        elif action in ('L', 'locate'):
+            manager.led_locate()
+
         elif action == 'P':
             manager.show_summary(_build_print_data())
-            manager.show_commands()
+            show_commands = True
 
         else:
             print('Notice: {!r} action unknown'.format(action))
@@ -585,7 +596,7 @@ def get_author_and_location():
     return author, location
 
 
-def dev_menu(devname, action):
+def dev_menu(devname, action, owner):
     if os.getuid() != 0:
         warn('Expected UID 0 (root) for access')
     author, location = get_author_and_location()
@@ -633,7 +644,7 @@ def dev_menu(devname, action):
         hdd_dock=hdd_dock, hdd_id=hdd_id,
         inventory_rest_client=inventory_rest_client,
         static_data=static_data, dynamic_data=dynamic_data,
-        author=author, location=location, action=action)
+        author=author, location=location, auto_action=action, owner=owner)
 
 
 def db_menu(serial):
@@ -663,25 +674,31 @@ def db_menu(serial):
 
 
 class AutoServer:
-    def __init__(self, action, gui, ignore_devices):
+    def __init__(self, action, gui, ignore_devices, owner):
         self.action = action
         self.gui = gui
         self.ignore_devices = [i.resolve() for i in ignore_devices]
+        self.owner = owner
         # Make sure the environment is valid to start osso-docktool.
-        author, location = get_author_and_location()
+        self.author, self.location = get_author_and_location()
         if not gui:
             if not os.environ.get('TMUX'):
-                os.execvp('tmux', [
+                args = [
                     'tmux', 'new', '-s', 'docktool', '-n', 'main',
-                    f'{self.docktool_exec} auto {action}'])
+                    self.docktool_exec, 'auto']
+                if self.owner:
+                    args += ['--owner', self.owner]
+                if self.action:
+                    args.extend(self.action)
+                os.execvp('tmux', args)
             else:
                 # Add the environment to the tmux session.
                 subprocess.check_call(
                     ['tmux', 'set', 'remain-on-exit', 'on'])
                 subprocess.check_call(
-                    ['tmux', 'setenv', 'EMAIL', author])
+                    ['tmux', 'setenv', 'EMAIL', self.author])
                 subprocess.check_call(
-                    ['tmux', 'setenv', 'LOCATION', location])
+                    ['tmux', 'setenv', 'LOCATION', self.location])
 
     def start(self):
         try:
@@ -694,11 +711,24 @@ class AutoServer:
             sock.bind(('127.0.0.1', 1451))
             sock.listen(4)
             sock.setblocking(True)
+            print('osso-docktool automatic™')
+            print(
+                '\x1b[1mBEWARE:\x1b[0m All your actions will be recorded '
+                f'as performed by: \x1b[1;32m{self.author}\x1b[0m\n'
+                'Change EMAIL envvar if it is incorrect!')
+            print(
+                '\x1b[1mBEWARE:\x1b[0m LOCATION is set to: \x1b[1;32m'
+                f'{self.location}\x1b[0m\n'
+                'Change to "OSSO HQ: HDD docktool" if in the office.')
+            print('Actions:', ', '.join(self.action))
+            if any(i in self.action for i in ('quick-erase', 'secure-erase')):
+                print('\x1b[1mBEWARE:\x1b[0m this will destroy the data on '
+                      'newly connected disks without confirmation !')
             if self.ignore_devices:
                 print(
-                    'Ignoring devices',
+                    'Ignoring devices:',
                     ','.join([str(i) for i in self.ignore_devices]))
-            print('Waiting for new disk notifications...')
+            print('Waiting for disk notifications...')
             while True:
                 connection, address = sock.accept()
                 pid = os.fork()
@@ -744,11 +774,8 @@ class AutoServer:
         print(f'Starting GUI terminal for {device}')
         # Double fork to detach terminal from pid group.
         if os.fork() == 0:
-            args = [
-                f'osso-docktool-terminal [{device}]', '-e',
-                'sudo', '-E', self.docktool_exec, 'dev', device, '--wait']
-            if self.action != 'start':
-                args += ['--action', self.action]
+            args = [f'osso-docktool-terminal [{device}]', '-e']
+            args += self.get_docktool_cmd(device)
             os.setsid()
             os.execvp('x-terminal-emulator', args)
         else:
@@ -760,14 +787,18 @@ class AutoServer:
             print('Error: TMUX environment variable is empty', file=sys.stderr)
         else:
             args = ['tmux', 'new-window', '-n', device]
-            cmd = (
-                f'sudo -E {self.docktool_exec} dev {shlex.quote(str(device))} '
-                '--wait')
-            if self.action != 'start':
-                cmd += f' --action {self.action}'
-            subprocess.check_call(args + [cmd])
+            args += self.get_docktool_cmd(device)
+            subprocess.check_call(args)
         os._exit(0)
 
+    def get_docktool_cmd(self, device):
+        cmd = ['sudo', '-E', self.docktool_exec, 'dev', device, '--wait']
+        for action in self.action:
+            cmd += ['--action', action]
+        if self.owner:
+            cmd += ['--owner', self.owner]
+        return cmd
+
 
 def auto_notify(device):
     with socket(AF_INET, SOCK_STREAM) as sock:
@@ -797,8 +828,14 @@ class DocktoolArgumentParser(argparse.ArgumentParser):
             'device', metavar='DISK', type=self.block_device,
             help='Device to use for example: /dev/sda')
         devparser.add_argument(
-            '-a', '--action', choices=['secure-erase'],
-            help='Automatically execute the action.')
+            '-a', '--action', choices=[
+                'eject', 'print-label', 'print-health-label', 'locate',
+                'set-owner', 'quick-erase', 'secure-erase'],
+            action='append', default=[],
+            help='Automatically execute the actions in order.')
+        devparser.add_argument(
+            '-o', '--owner', metavar='OWNER', default='',
+            help='The owner to set for the set-owner action.')
         devparser.add_argument(
             '-w', '--wait', action='store_true',
             help='Wait for user confirmation before exit.')
@@ -823,8 +860,16 @@ class DocktoolArgumentParser(argparse.ArgumentParser):
             type=self.block_device,
             help='Ignore the device for auto commands.')
         autoparser.add_argument(
-            'action', choices=['start', 'secure-erase'], default='start',
-            help='Start docktool or secure erase newly inserted disks')
+            '-o', '--owner', metavar='OWNER',
+            help='The owner to set for the set-owner action.')
+        autoparser.add_argument(
+            # https://bugs.python.org/issue27227
+            # Add [] to choices to make actions optional.
+            'action', nargs='*', choices=[
+                'eject', 'print-label', 'print-health-label', 'locate',
+                'set-owner', 'quick-erase', 'secure-erase', []],
+            help='Start docktool and perform these actions in order '
+                 '(default: start osso-docktool, no extra action).')
 
         notifyparser = self.subparsers.add_parser(
             'auto-notify',
@@ -865,9 +910,8 @@ class DocktoolArgumentParser(argparse.ArgumentParser):
     def block_device(self, name):
         device = Path(name)
         if not device.is_absolute():
-            ret = self.block_device('/dev' / device)
             warn('Prepended /dev/ to the block device name')
-            return ret
+            return self.block_device('/dev' / device)
         if not device.exists():
             self.message2 = f'{device!r}: not found'
             raise argparse.ArgumentError(f'{device}: not found')
@@ -883,11 +927,11 @@ def main():
 
     try:
         if args.command == 'dev':
-            dev_menu(args.device, args.action)
+            dev_menu(args.device, args.action, args.owner)
         elif args.command == 'serial':
             db_menu(args.serial)
         elif args.command == 'auto':
-            AutoServer(args.action, args.gui, args.ignore).start()
+            AutoServer(args.action, args.gui, args.ignore, args.owner).start()
         elif args.command == 'auto-notify':
             auto_notify(args.device)
     except KeyboardInterrupt:
