@@ -111,6 +111,15 @@ class BaseStorageDevice(object):
 
         return port or self.devname
 
+    def led(self, pattern='locate'):
+        subprocess.check_call(['ledctl', '-x', f'{pattern}={self.devname}'])
+
+    def led_failure(self):
+        self.led('failure')
+
+    def led_locate(self):
+        self.led('locate')
+
     def get_erase_methods(self):
         return [self.wipe_using_manual_methods]
 
